@@ -1,14 +1,14 @@
-# Copyrights 2001-2008 by Mark Overmeer.
+# Copyrights 2001-2010 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.05.
+# Pod stripped from pm file by OODoc 1.06.
 
 use strict;
 use warnings;
 
 package Mail::Box;
 use vars '$VERSION';
-$VERSION = '2.086';
+$VERSION = '2.094';
 
 use base 'Mail::Reporter';
 
@@ -20,11 +20,6 @@ use Carp;
 use Scalar::Util 'weaken';
 use List::Util   qw/sum first/;
 
-#-------------------------------------------
-# Clean exits required to remove lockfiles and to save changes.
-
-$SIG{INT} = $SIG{QUIT} = $SIG{PIPE} = $SIG{TERM} = sub {exit 0};
-
 
 #-------------------------------------------
 
@@ -141,6 +136,7 @@ sub init($)
           , timeout  => $args->{lock_timeout}
           , expires  => $args->{lock_wait}
           , file     => ($args->{lockfile} || $args->{lock_file})
+          , $self->logSettings
           );
 
     $self;
@@ -157,31 +153,21 @@ sub folderdir(;$)
 
 sub foundIn($@) { shift->notImplemented }
 
-#-------------------------------------------
-
 
 sub name() {shift->{MB_foldername}}
 
-#-------------------------------------------
-
 
 sub type() {shift->notImplemented}
 
-#-------------------------------------------
-
 
 sub url()
 {   my $self = shift;
     $self->type . ':' . $self->name;
 }
 
-#-------------------------------------------
-
 
 sub size() { sum map { $_->size } shift->messages('ACTIVE') }
 
-#-------------------------------------------
-
 
 sub update(@)
 {   my $self = shift;
@@ -199,13 +185,9 @@ sub update(@)
     $self;
 }
 
-#-------------------------------------------
-
 
 sub organization() { shift->notImplemented }
 
-#-------------------------------------------
-
 
 sub addMessage($@)
 {   my $self    = shift;
@@ -240,17 +222,12 @@ ERROR
     $coerced;
 }
 
-#-------------------------------------------
-
-
 
 sub addMessages(@)
 {   my $self = shift;
     map {$self->addMessage($_)} @_;
 }
 
-#-------------------------------------------
-
 
 sub copyTo($@)
 {   my ($self, $to, %args) = @_;
@@ -329,8 +306,6 @@ sub _copy_to($@)
     $self;
 }
 
-#-------------------------------------------
-
 
 sub close(@)
 {   my ($self, %args) = @_;
@@ -371,8 +346,6 @@ Suggestion: \$folder->close(write => 'NEVER')");
     $rc;
 }
 
-#-------------------------------------------
-
 
 sub delete(@)
 {   my ($self, %args) = @_;
@@ -611,6 +584,7 @@ sub scanForMessages($$$$)
     # Set-up time-bound
     my $after = $moment eq 'EVER'   ? 0
               : $moment =~ m/^\d+$/ ? $moment
+              : !$startmsg          ? 0
               : $startmsg->timestamp - $self->timespan2seconds($moment);
 
     while($last >= $bound)
@@ -715,7 +689,9 @@ sub write(@)
     }
 
     my (@keep, @destroy);
-    if($args{save_deleted}) {@keep = $self->messages }
+    if($args{save_deleted})
+    {   @keep = $self->messages;
+    }
     else
     {   foreach ($self->messages)
         {   if($_->isDeleted)
