@@ -1,13 +1,13 @@
-# Copyrights 2001-2008 by Mark Overmeer.
+# Copyrights 2001-2010 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.04.
+# Pod stripped from pm file by OODoc 1.06.
 
 use strict;
 
 package Mail::Box::Locker::DotLock;
 use vars '$VERSION';
-$VERSION = '2.082';
+$VERSION = '2.094';
 
 use base 'Mail::Box::Locker';
 
@@ -19,27 +19,30 @@ use Carp;
 
 sub init($)
 {   my ($self, $args) = @_;
-
-    unless($args->{file})
-    {   my $folder = $args->{folder}
-           or confess;
-
-        my $org    = $folder->organization;
-
-        $args->{file}
-         = $org eq 'FILE'      ? $folder->filename . '.lock'
-         : $org eq 'DIRECTORY' ? File::Spec->catfile($folder->directory,'.lock')
-         : croak "Need lock file name for DotLock.";
-    }
-
+    $args->{file} = $args->{dotlock_file} if $args->{dotlock_file};
     $self->SUPER::init($args);
 }
 
-#-------------------------------------------
-
 sub name() {'DOTLOCK'}
 
-#-------------------------------------------
+sub folder(;$)
+{   my $self = shift;
+    @_ && $_[0] or return $self->SUPER::folder;
+
+    my $folder = shift;
+    unless(defined $self->filename)
+    {   my $org = $folder->organization;
+
+        my $filename
+          = $org eq 'FILE'     ? $folder->filename . '.lock'
+          : $org eq 'DIRECTORY'? File::Spec->catfile($folder->directory,'.lock')
+          : croak "Need lock file name for DotLock.";
+
+        $self->filename($filename);
+    }
+
+    $self->SUPER::folder($folder);
+}
 
 sub _try_lock($)
 {   my ($self, $lockfile) = @_;
@@ -61,8 +64,6 @@ sub _try_lock($)
     }
 }
 
-#-------------------------------------------
-
 
 sub unlock()
 {   my $self = shift;
@@ -78,8 +79,6 @@ sub unlock()
     $self;
 }
 
-#-------------------------------------------
-
 
 sub lock()
 {   my $self   = shift;
@@ -119,11 +118,7 @@ sub lock()
     return 0;
 }
 
-#-------------------------------------------
-
 sub isLocked() { -e shift->filename }
 
-#-------------------------------------------
-
 1;
 
