@@ -1,13 +1,13 @@
-# Copyrights 2001-2008 by Mark Overmeer.
+# Copyrights 2001-2010 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.05.
+# Pod stripped from pm file by OODoc 1.06.
 use strict;
 use warnings;
 
 package Mail::Message::Body;
 use vars '$VERSION';
-$VERSION = '2.086';
+$VERSION = '2.094';
 
 use base 'Mail::Reporter';
 
@@ -130,16 +130,15 @@ sub init($)
         $self->{MMB_checked} = $args->{checked} || 0;
     }
 
-    if(defined $mime)
-    {   $mime = $self->type($mime);
-        $mime->attribute(charset => ($charset || 'PERL'))
-            if $mime =~ m!^text/!i && !$mime->attribute('charset');
-    }
+    $mime ||= 'text/plain';
+    $mime = $self->type($mime);
+    $mime->attribute(charset => ($charset || 'PERL'))
+        if $mime =~ m!^text/!i && !$mime->attribute('charset');
 
     $self->transferEncoding($transfer) if defined $transfer;
     $self->disposition($disp)          if defined $disp;
     $self->description($descr)         if defined $descr;
-    $self->type($mime) if defined $mime;
+    $self->type($mime);
 
     $self->{MMB_eol}   = $args->{eol} || 'NATIVE';
 
@@ -152,8 +151,6 @@ sub init($)
     $self;
 }
 
-#------------------------------------------
-
 
 sub clone() {shift->notImplemented}
 
@@ -170,8 +167,6 @@ sub decoded(@)
      );
 }
 
-#------------------------------------------
-
 
 sub eol(;$)
 {   my $self = shift;
@@ -184,15 +179,20 @@ sub eol(;$)
              :                   'LF';
     }
 
-    return $eol if $eol eq $self->{MMB_eol} && $self->checked;
+    return $self if $eol eq $self->{MMB_eol} && $self->checked;
     my $lines = $self->lines;
+    if(@$lines)
+    {   # sometimes texts lack \n on last line
+        $lines->[-1] .= "\n";
+       
 
-       if($eol eq 'CR')    {s/[\015\012]+$/\015/     foreach @$lines}
-    elsif($eol eq 'LF')    {s/[\015\012]+$/\012/     foreach @$lines}
-    elsif($eol eq 'CRLF')  {s/[\015\012]+$/\015\012/ foreach @$lines}
-    else
-    {   $self->log(WARNING => "Unknown line terminator $eol ignored.");
-        return $self->eol('NATIVE');
+           if($eol eq 'CR')   {s/[\015\012]+$/\015/     for @$lines}
+        elsif($eol eq 'LF')   {s/[\015\012]+$/\012/     for @$lines}
+        elsif($eol eq 'CRLF') {s/[\015\012]+$/\015\012/ for @$lines}
+        else
+        {   $self->log(WARNING => "Unknown line terminator $eol ignored");
+            return $self->eol('NATIVE');
+        }
     }
 
     (ref $self)->new
@@ -214,18 +214,12 @@ sub message(;$)
     $self->{MMB_message};
 }
 
-#------------------------------------------
-
 
 sub isDelayed() {0}
 
-#------------------------------------------
-
 
 sub isMultipart() {0}
 
-#------------------------------------------
-
 
 sub isNested() {0}
 
@@ -261,13 +255,9 @@ sub mimeType()
        = $mime_types->type($body) || MIME::Type->new(type => $body);
 }
 
-#------------------------------------------
-
 
 sub charset() { shift->type->attribute('charset') }
 
-#------------------------------------------
-
 
 sub transferEncoding(;$)
 {   my $self = shift;
@@ -279,9 +269,6 @@ sub transferEncoding(;$)
 }
 
 
-#------------------------------------------
-
-
 sub description(;$)
 {   my $self = shift;
     return $self->{MMB_description} if !@_ && $self->{MMB_description};
@@ -291,8 +278,6 @@ sub description(;$)
        : Mail::Message::Field->new('Content-Description' => $disp);
 }
 
-#------------------------------------------
-
 
 sub disposition(;$)
 {   my $self = shift;
@@ -304,21 +289,15 @@ sub disposition(;$)
        : Mail::Message::Field->new('Content-Disposition' => $disp);
 }
 
-#------------------------------------------
-
 
 sub checked(;$)
 {   my $self = shift;
     @_ ? ($self->{MMB_checked} = shift) : $self->{MMB_checked};
 }
 
-#------------------------------------------
-
 
 sub nrLines(@)  {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub size(@)  {shift->notImplemented}
 
@@ -335,28 +314,18 @@ sub string_unless_carp()
     "$class object";
 }
 
-#------------------------------------------
-
 
 sub lines() {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub file(;$) {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub print(;$) {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub printEscapedFrom($) {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub write(@)
 {   my ($self, %args) = @_;
@@ -369,13 +338,9 @@ sub write(@)
     $self;
 }
 
-#------------------------------------------
-
 
 sub endsOnNewline() {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub stripTrailingNewline() {shift->notImplemented}
 
@@ -384,8 +349,6 @@ sub stripTrailingNewline() {shift->notImplemented}
 
 sub read(@) {shift->notImplemented}
 
-#------------------------------------------
-
 
 sub contentInfoTo($)
 {   my ($self, $head) = @_;
@@ -402,8 +365,6 @@ sub contentInfoTo($)
     $self;
 }
 
-#------------------------------------------
-
 
 sub contentInfoFrom($)
 {   my ($self, $head) = @_;
@@ -417,7 +378,6 @@ sub contentInfoFrom($)
     $self;
 
 }
-#------------------------------------------
 
 
 sub modified(;$)
@@ -426,22 +386,16 @@ sub modified(;$)
    $self->{MMB_modified} = shift;
 }
 
-#------------------------------------------
+
+sub isModified() { shift->{MMB_modified} }
 
 
-sub isModified() {  shift->{MMB_modified} }
-
-#------------------------------------------
-
-
-sub fileLocation(;@) {
-    my $self = shift;
+sub fileLocation(;@)
+{   my $self = shift;
     return @$self{ qw/MMB_begin MMB_end/ } unless @_;
     @$self{ qw/MMB_begin MMB_end/ } = @_;
 }
 
-#------------------------------------------
-
 
 sub moveLocation($)
 {   my ($self, $dist) = @_;
@@ -450,8 +404,6 @@ sub moveLocation($)
     $self;
 }
 
-#------------------------------------------
-
 
 sub load() {shift}
 
