@@ -1,13 +1,13 @@
-# Copyrights 2001-2008 by Mark Overmeer.
+# Copyrights 2001-2010 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.04.
+# Pod stripped from pm file by OODoc 1.06.
 use strict;
 use warnings;
 
 package Mail::Message::Body::Nested;
 use vars '$VERSION';
-$VERSION = '2.082';
+$VERSION = '2.094';
 
 use base 'Mail::Message::Body';
 
@@ -35,16 +35,10 @@ sub init($)
     $self;
 }
 
-#------------------------------------------
-
 sub isNested() {1}
 
-#------------------------------------------
-
 sub isBinary() { shift->nested->body->isBinary }
 
-#------------------------------------------
-
 sub clone()
 {   my $self     = shift;
 
@@ -55,44 +49,30 @@ sub clone()
      );
 }
 
-#------------------------------------------
-
 sub nrLines() { shift->nested->nrLines }
 
-#------------------------------------------
-
 sub size()    { shift->nested->size }
 
-#------------------------------------------
-
 sub string()
 {    my $nested = shift->nested;
      defined $nested ? $nested->string : '';
 }
 
-#------------------------------------------
-
 sub lines()
 {    my $nested = shift->nested;
      defined $nested ? ($nested->lines) : ();
 }
 
-#------------------------------------------
-
 sub file()
 {    my $nested = shift->nested;
      defined $nested ? $nested->file : undef;
 }
 
-#------------------------------------------
-
 sub print(;$)
 {   my $self = shift;
     $self->nested->print(shift || select);
 }
 
-#------------------------------------------
-
 
 sub foreachLine($)
 {   my ($self, $code) = @_;
@@ -100,24 +80,15 @@ sub foreachLine($)
     confess;
 }
 
-
-#------------------------------------------
-
 sub check() { shift->forNested( sub {$_[1]->check} ) }
 
-#------------------------------------------
-
 sub encode(@)
 {   my ($self, %args) = @_;
     $self->forNested( sub {$_[1]->encode(%args)} );
 }
 
-#------------------------------------------
-
 sub encoded() { shift->forNested( sub {$_[1]->encoded} ) }
 
-#------------------------------------------
-
 sub read($$$$)
 {   my ($self, $parser, $head, $bodytype) = @_;
 
@@ -130,8 +101,6 @@ sub read($$$$)
     $self;
 }
 
-#-------------------------------------------
-
 sub fileLocation()
 {   my $nested   = shift->nested;
 
@@ -140,12 +109,8 @@ sub fileLocation()
     );
 }
 
-#-------------------------------------------
-
 sub endsOnNewline() { shift->nested->body->endsOnNewline }
 
-#------------------------------------------
-
 sub moveLocation($)
 {   my $self   = shift;
     my $nested = $self->nested;
@@ -156,13 +121,9 @@ sub moveLocation($)
     $self;
 }
 
-#------------------------------------------
-
 
 sub nested() { shift->{MMBN_nested} }
 
-#------------------------------------------
-
 
 sub forNested($)
 {   my ($self, $code) = @_;
@@ -190,6 +151,6 @@ sub forNested($)
     $created;
 }
 
-#-------------------------------------------
+sub toplevel() { my $msg = shift->message; $msg ? $msg->toplevel : undef}
 
 1;
