@@ -1,13 +1,13 @@
-# Copyrights 2001-2008 by Mark Overmeer.
+# Copyrights 2001-2010 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.05.
+# Pod stripped from pm file by OODoc 1.06.
 
 use strict;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '2.086';
+$VERSION = '2.094';
 
 
 use Mail::Message::Body::Multipart;
@@ -77,45 +77,33 @@ sub reply(@)
     my $mainhead = $self->toplevel->head;
 
     # Where it comes from
-    my $from = $args{From};
+    my $from = delete $args{From};
     unless(defined $from)
     {   my @from = $self->to;
         $from    = \@from if @from;
     }
 
     # To whom to send
-    my $to = $args{To};
-    unless(defined $to)
-    {   my $reply = $mainhead->get('reply-to');
-        $to       = [ $reply->addresses ] if defined $reply;
-    }
-
-    unless(defined $to)
-    {   my @from  = $self->from;
-        $to     ||= \@from if @from;
-    }
-
+    my $to = delete $args{To}
+          || $mainhead->get('reply-to') || $mainhead->get('from');
     defined $to or return;
 
     # Add Cc
-    my $cc = $args{Cc};
+    my $cc = delete $args{Cc};
     if(!defined $cc && $args{group_reply})
     {   my @cc = $self->cc;
         $cc    = [ $self->cc ] if @cc;
     }
 
-    # Add Bcc
-    my $bcc = $args{Bcc};
-
     # Create a subject
-    my $srcsub  = $args{Subject};
+    my $srcsub  = delete $args{Subject};
     my $subject
      = ! defined $srcsub ? $self->replySubject($self->subject)
      : ref $srcsub       ? $srcsub->($self->subject)
      :                     $srcsub;
 
     # Create a nice message-id
-    my $msgid   = $args{'Message-ID'};
+    my $msgid   = delete $args{'Message-ID'};
     $msgid      = "<$msgid>" if $msgid && $msgid !~ /^\s*\<.*\>\s*$/;
 
     # Thread information
@@ -177,7 +165,9 @@ sub reply(@)
 
     my $newhead = $reply->head;
     $newhead->set(Cc  => $cc)  if $cc;
-    $newhead->set(Bcc => $args{Bcc}) if $args{Bcc};
+    $newhead->set(Bcc => delete $args{Bcc}) if $args{Bcc};
+    $newhead->add($_ => $args{$_})
+        for sort grep /^[A-Z]/, keys %args;
 
     # Ready
 
