@@ -1,4 +1,4 @@
-# Copyrights 2001-2009 by Mark Overmeer.
+# Copyrights 2001-2010 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 1.06.
@@ -7,7 +7,7 @@ use warnings;
 
 package Mail::Message::Field::Addresses;
 use vars '$VERSION';
-$VERSION = '2.093';
+$VERSION = '2.094';
 
 use base 'Mail::Message::Field::Structured';
 
@@ -122,6 +122,7 @@ sub addAttribute($;@)
 sub parse($)
 {   my ($self, $string) = @_;
     my ($group, $email) = ('', undef);
+    $string =~ s/\s+/ /gs;
 
     while(1)
     {   (my $comment, $string) = $self->consumeComment($string);
@@ -154,8 +155,8 @@ sub parse($)
             my $angle;
             if($string =~ s/^\s*\<([^>]*)\>//s) { $angle = $1 }
             elsif($real_phrase)
-            {   $string =~ s/^\s*\"(.*?)\r?\n//;
-                $self->log(ERROR => "Ignore unrelated phrase `$1'");
+            {   $self->log(ERROR => "Ignore unrelated phrase `$1'")
+                    if $string =~ s/^\s*\"(.*?)\r?\n//;
                 next;
             }
             elsif(defined $phrase)
